@@ -65,14 +65,14 @@ void TotpUriParser::validateUrl(QString original)
         throw std::runtime_error("Empty url!");
     }
 
-    const QString SUPPORTED_SHEME = "otpauth://totp/";
-    const int SHEME_LEN = SUPPORTED_SHEME.length();
-    QString sheme = original.left(SHEME_LEN);
-    qDebug() << "Detected sheme: " << sheme;
+    const QString SUPPORTED_SCHEME = "otpauth://totp/";
+    const int SCHEME_LEN = SUPPORTED_SCHEME.length();
+    QString scheme = original.left(SCHEME_LEN);
+    qDebug() << "Detected scheme: " << scheme;
 
-    int cmp = QString::compare(SUPPORTED_SHEME, sheme, Qt::CaseSensitive);
+    int cmp = QString::compare(SUPPORTED_SCHEME, scheme, Qt::CaseSensitive);
     if (cmp != 0) {
-        throw std::runtime_error("Wrong sheme!");
+        throw std::runtime_error("Wrong scheme!");
     }
 }
 
