@@ -199,7 +199,7 @@ TEST(TotpUrlParserTest, WrongScheme) {
 
         } catch(const std::runtime_error& e) {
             // Then
-            ASSERT_STREQ("Wrong sheme!", e.what());
+            ASSERT_STREQ("Wrong scheme!", e.what());
             throw;
         }
     }, std::runtime_error);
